@@ -3,7 +3,7 @@ use strict;
 
 package PINE64::MCP9808;
 
-our $VERSION = '0.901';
+our $VERSION = '0.903';
 
 #global vars
 my ($i2cbus, $addr) = ('','');
@@ -74,7 +74,7 @@ PINE64A+ board.
 
 =head1 METHODS
 
-==head2 new(0, '0x18')
+==head2 new(0, 0x18)
 
 You can optionally pass the I2C device id and the address of the
 MCP9808 on the I2C bus.  The PINE64A+ I2C bus is /dev/i2c-0, and
